@@ -17,7 +17,17 @@ namespace IPod {
         NanoWhite,
         NanoBlack,
         VideoWhite,
-        VideoBlack
+        VideoBlack,
+        NanoSilver,
+        NanoGreen,
+        NanoBlue,
+        NanoPink,
+        NanoProductRed,
+        ShuffleSilver,
+        ShufflePink,
+        ShuffleBlue,
+        ShuffleGreen,
+        ShuffleOrange
     }
 }
 
