@@ -5,8 +5,6 @@ using System.Collections.Generic;
 using System.Collections.ObjectModel;
 using System.Runtime.InteropServices;
 using System.IO;
-using Mono.Unix;
-using Mono.Unix.Native;
 
 namespace IPod {
 
@@ -897,7 +895,7 @@ namespace IPod {
         public FileRecord LookupFile (int correlationId) {
             try {
                 return files[correlationId];
-            } catch (KeyNotFoundException e) {
+            } catch (KeyNotFoundException) {
                 return null;
             }
         }
@@ -1005,11 +1003,9 @@ namespace IPod {
 
         private string PhotoDbPath {
             get {
-                if (isPhoto) {
-                    return device.MountPoint + "/Photos/Photo Database";
-                } else {
-                    return device.ControlPath + "/Artwork/ArtworkDB";
-                }
+                return isPhoto 
+                    ? String.Format ("{0}{1}Photos{1}Photo Database", device.VolumeInfo.MountPoint, Path.DirectorySeparatorChar)
+                    : String.Format ("{0}{1}Artwork{1}ArtworkDB", device.ControlPath, Path.DirectorySeparatorChar);
             }
         }
 
@@ -1228,29 +1224,35 @@ namespace IPod {
 
         internal Photo LookupPhotoById (int id) {
             try {
+                if (!photos.ContainsKey(id))
+                    return null;
+
                 return photos[id];
-            } catch (KeyNotFoundException e) {
+            } catch (KeyNotFoundException) {
                 return null;
             }
         }
 
         internal Photo LookupPhotoByTrackId (long id) {
             try {
+                if (!trackPhotos.ContainsKey(id))
+                    return null;
+
                 return trackPhotos[id];
-            } catch (KeyNotFoundException e) {
+            } catch (KeyNotFoundException) {
                 return null;
             }
         }
 
         internal string GetFilesystemPath (string podpath) {
-            return String.Format ("{0}/Photos{1}", device.MountPoint, podpath.Replace(':', '/'));
+            return String.Format ("{0}{1}Photos{2}", device.VolumeInfo.MountPoint, podpath.Replace(':', '/'), Path.DirectorySeparatorChar);
         }
 
         internal string GetThumbPath (ArtworkFormat format) {
             if (isPhoto) {
-                return String.Format ("{0}/Photos/Thumbs/F{1}_1.ithmb", device.MountPoint, format.CorrelationId);
+                return String.Format ("{0}{2}Photos{2}Thumbs{2}F{1}_1.ithmb", device.VolumeInfo.MountPoint, format.CorrelationId, Path.DirectorySeparatorChar);
             } else {
-                return String.Format ("{0}/Artwork/F{1}_1.ithmb", device.ControlPath, format.CorrelationId);
+                return String.Format ("{0}{2}Artwork{2}F{1}_1.ithmb", device.ControlPath, format.CorrelationId, Path.DirectorySeparatorChar);
             }
 
         }
@@ -1395,9 +1397,9 @@ namespace IPod {
                         existing.SetData (stream, data);
                     }
                 }
-            }
 
-            Syscall.truncate (thumbPath, (long) fileLength);
+                stream.SetLength(fileLength);
+            }
         }
 
         internal Stream GetTempFile () {
